@@ -1,14 +1,32 @@
-if False:
+from jina.serve.runtimes.head import HeadRuntime
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
     from argparse import Namespace
 
 
+def deployment(args: 'Namespace'):
+    """
+    Start a Deployment
+
+    :param args: arguments coming from the CLI.
+    """
+    from jina.orchestrate.deployments import Deployment
+
+    try:
+        with Deployment(args) as d:
+            d.join()
+    except KeyboardInterrupt:
+        pass
+
+
 def pod(args: 'Namespace'):
     """
     Start a Pod
 
     :param args: arguments coming from the CLI.
     """
-    from jina.peapods.pods.factory import PodFactory
+    from jina.orchestrate.pods.factory import PodFactory
 
     try:
         with PodFactory.build_pod(args) as p:
@@ -17,37 +35,88 @@ def pod(args: 'Namespace'):
         pass
 
 
-def pea(args: 'Namespace'):
+def executor_native(args: 'Namespace'):
     """
-    Start a Pea
+    Starts an Executor in a WorkerRuntime
 
     :param args: arguments coming from the CLI.
     """
-    from jina.peapods import Pea
+    from jina.serve.runtimes.worker import WorkerRuntime
 
-    try:
-        with Pea(args) as p:
-            p.join()
-    except KeyboardInterrupt:
-        pass
+    if args.runtime_cls == 'WorkerRuntime':
+        runtime_cls = WorkerRuntime
+    elif args.runtime_cls == 'HeadRuntime':
+        runtime_cls = HeadRuntime
+    else:
+        raise RuntimeError(
+            f' runtime_cls {args.runtime_cls} is not supported with `--native` argument. `WorkerRuntime` is supported'
+        )
+
+    with runtime_cls(args) as rt:
+        name = (
+            rt._data_request_handler._executor.metas.name
+            if hasattr(rt, '_data_request_handler')
+            else rt.name
+        )
+        rt.logger.success(f' Executor {name} started')
+        rt.run_forever()
 
 
-# alias
-executor = pea
+def executor(args: 'Namespace'):
+    """
+    Starts an Executor in any Runtime
+
+    :param args: arguments coming from the CLI.
+
+    :returns: return the same as `pod` or `worker_runtime`
+    """
+    if args.native:
+        return executor_native(args)
+    else:
+        return pod(args)
+
+
+def worker_runtime(args: 'Namespace'):
+    """
+    Starts a WorkerRuntime
+
+    :param args: arguments coming from the CLI.
+    """
+    from jina.serve.runtimes.worker import WorkerRuntime
+
+    with WorkerRuntime(args) as runtime:
+        runtime.logger.success(
+            f' Executor {runtime._data_request_handler._executor.metas.name} started'
+        )
+        runtime.run_forever()
 
 
 def gateway(args: 'Namespace'):
     """
-    Start a Gateway Pod
+    Start a Gateway Deployment
 
     :param args: arguments coming from the CLI.
     """
-    pod(args)
+    from jina.enums import GatewayProtocolType
+    from jina.serve.runtimes import get_runtime
+
+    gateway_runtime_dict = {
+        GatewayProtocolType.GRPC: 'GRPCGatewayRuntime',
+        GatewayProtocolType.WEBSOCKET: 'WebSocketGatewayRuntime',
+        GatewayProtocolType.HTTP: 'HTTPGatewayRuntime',
+    }
+    runtime_cls = get_runtime(gateway_runtime_dict[args.protocol])
+
+    with runtime_cls(args) as runtime:
+        runtime.logger.success(
+            f' Gateway with protocol {gateway_runtime_dict[args.protocol]} started'
+        )
+        runtime.run_forever()
 
 
 def ping(args: 'Namespace'):
     """
-    Check the connectivity of a Pea
+    Check the connectivity of a Pod
 
     :param args: arguments coming from the CLI.
     """
@@ -74,7 +143,7 @@ def export_api(args: 'Namespace'):
     :param args: arguments coming from the CLI.
     """
     import json
-    from .export import api_to_dict
+    from cli.export import api_to_dict
     from jina.jaml import JAML
     from jina import __version__
     from jina.logging.predefined import default_logger
@@ -147,17 +216,6 @@ def flow(args: 'Namespace'):
         raise ValueError('start a flow from CLI requires a valid `--uses`')
 
 
-def optimizer(args: 'Namespace'):
-    """
-    Start an optimization from a YAML file
-
-    :param args: arguments coming from the CLI.
-    """
-    from jina.optimizers import run_optimizer_cli
-
-    run_optimizer_cli(args)
-
-
 def hub(args: 'Namespace'):
     """
     Start a hub builder for push, pull
@@ -174,6 +232,6 @@ def help(args: 'Namespace'):
 
     :param args: arguments coming from the CLI.
     """
-    from .lookup import lookup_and_print
+    from cli.lookup import lookup_and_print
 
     lookup_and_print(args.query.lower())
