@@ -10,8 +10,8 @@ ac_table = {
         'gateway',
         'hub',
         'help',
-        'pea',
         'pod',
+        'deployment',
         'client',
         'export-api',
     ],
@@ -50,45 +50,23 @@ ac_table = {
             '--help',
             '--name',
             '--workspace',
-            '--k8s-namespace',
             '--log-config',
             '--quiet',
             '--quiet-error',
-            '--identity',
             '--workspace-id',
-            '--static-routing-table',
-            '--routing-table',
-            '--dynamic-routing',
             '--extra-search-paths',
-            '--zmq-identity',
-            '--port-ctrl',
-            '--ctrl-with-ipc',
             '--timeout-ctrl',
-            '--ssh-server',
-            '--ssh-keyfile',
-            '--ssh-password',
+            '--k8s-namespace',
+            '--k8s-disable-connection-pool',
+            '--polling',
             '--uses',
             '--uses-with',
             '--uses-metas',
             '--uses-requests',
             '--py-modules',
             '--port-in',
-            '--port-out',
-            '--hosts-in-connect',
             '--host-in',
-            '--host-out',
-            '--socket-in',
-            '--socket-out',
-            '--memory-hwm',
-            '--on-error-strategy',
             '--native',
-            '--num-part',
-            '--dynamic-routing-out',
-            '--dynamic-routing-in',
-            '--grpc-data-requests',
-            '--runs-in-docker',
-            '--dump-path',
-            '--k8s-disable-connection-pool',
             '--entrypoint',
             '--docker-kwargs',
             '--pull-latest',
@@ -107,79 +85,57 @@ ac_table = {
             '--env',
             '--expose-public',
             '--shard-id',
-            '--pea-id',
             '--replica-id',
-            '--pea-role',
+            '--pod-role',
             '--noblock-on-start',
             '--shards',
-            '--parallel',
             '--replicas',
             '--install-requirements',
             '--force-update',
             '--force',
+            '--uses-before-address',
+            '--uses-after-address',
+            '--connection-list',
         ],
         'flow': [
             '--help',
             '--name',
             '--workspace',
-            '--k8s-namespace',
             '--log-config',
             '--quiet',
             '--quiet-error',
             '--workspace-id',
-            '--static-routing-table',
-            '--routing-table',
-            '--dynamic-routing',
             '--extra-search-paths',
+            '--timeout-ctrl',
+            '--k8s-namespace',
+            '--k8s-disable-connection-pool',
+            '--polling',
             '--uses',
             '--env',
             '--inspect',
-            '--infrastructure',
         ],
-        'ping': ['--help', '--timeout', '--retries', '--print-response'],
+        'ping': ['--help', '--timeout', '--retries'],
         'gateway': [
             '--help',
             '--name',
             '--workspace',
-            '--k8s-namespace',
             '--log-config',
             '--quiet',
             '--quiet-error',
-            '--identity',
             '--workspace-id',
-            '--static-routing-table',
-            '--routing-table',
-            '--dynamic-routing',
             '--extra-search-paths',
-            '--zmq-identity',
-            '--port-ctrl',
-            '--ctrl-with-ipc',
             '--timeout-ctrl',
-            '--ssh-server',
-            '--ssh-keyfile',
-            '--ssh-password',
+            '--k8s-namespace',
+            '--k8s-disable-connection-pool',
+            '--polling',
             '--uses',
             '--uses-with',
             '--uses-metas',
             '--uses-requests',
             '--py-modules',
             '--port-in',
-            '--port-out',
-            '--hosts-in-connect',
             '--host-in',
-            '--host-out',
-            '--socket-in',
-            '--socket-out',
-            '--memory-hwm',
-            '--on-error-strategy',
             '--native',
-            '--num-part',
-            '--dynamic-routing-out',
-            '--dynamic-routing-in',
-            '--grpc-data-requests',
-            '--runs-in-docker',
-            '--dump-path',
-            '--k8s-disable-connection-pool',
             '--prefetch',
             '--title',
             '--description',
@@ -196,6 +152,8 @@ ac_table = {
             '--host',
             '--proxy',
             '--port-expose',
+            '--graph-description',
+            '--deployments-addresses',
             '--daemon',
             '--runtime-backend',
             '--runtime',
@@ -204,17 +162,14 @@ ac_table = {
             '--env',
             '--expose-public',
             '--shard-id',
-            '--pea-id',
             '--replica-id',
-            '--pea-role',
+            '--pod-role',
             '--noblock-on-start',
             '--shards',
-            '--parallel',
             '--replicas',
-            '--k8s-uses-init',
-            '--k8s-mount-path',
-            '--k8s-init-container-command',
-            '--k8s-custom-resource-dir',
+            '--uses-before-address',
+            '--uses-after-address',
+            '--connection-list',
         ],
         'hub new': [
             '--help',
@@ -229,6 +184,7 @@ ac_table = {
         'hub push': [
             '--help',
             '--no-usage',
+            '--verbose',
             '--dockerfile',
             '--tag',
             '--force-update',
@@ -246,121 +202,27 @@ ac_table = {
         ],
         'hub': ['--help', 'new', 'push', 'pull'],
         'help': ['--help'],
-        'pea': [
-            '--help',
-            '--name',
-            '--workspace',
-            '--k8s-namespace',
-            '--log-config',
-            '--quiet',
-            '--quiet-error',
-            '--identity',
-            '--workspace-id',
-            '--static-routing-table',
-            '--routing-table',
-            '--dynamic-routing',
-            '--extra-search-paths',
-            '--zmq-identity',
-            '--port-ctrl',
-            '--ctrl-with-ipc',
-            '--timeout-ctrl',
-            '--ssh-server',
-            '--ssh-keyfile',
-            '--ssh-password',
-            '--uses',
-            '--uses-with',
-            '--uses-metas',
-            '--uses-requests',
-            '--py-modules',
-            '--port-in',
-            '--port-out',
-            '--hosts-in-connect',
-            '--host-in',
-            '--host-out',
-            '--socket-in',
-            '--socket-out',
-            '--memory-hwm',
-            '--on-error-strategy',
-            '--native',
-            '--num-part',
-            '--dynamic-routing-out',
-            '--dynamic-routing-in',
-            '--grpc-data-requests',
-            '--runs-in-docker',
-            '--dump-path',
-            '--k8s-disable-connection-pool',
-            '--entrypoint',
-            '--docker-kwargs',
-            '--pull-latest',
-            '--volumes',
-            '--gpus',
-            '--host',
-            '--port-jinad',
-            '--quiet-remote-logs',
-            '--upload-files',
-            '--disable-remote',
-            '--daemon',
-            '--runtime-backend',
-            '--runtime',
-            '--runtime-cls',
-            '--timeout-ready',
-            '--env',
-            '--expose-public',
-            '--shard-id',
-            '--pea-id',
-            '--replica-id',
-            '--pea-role',
-            '--noblock-on-start',
-            '--shards',
-            '--parallel',
-            '--replicas',
-            '--install-requirements',
-            '--force-update',
-            '--force',
-        ],
         'pod': [
             '--help',
             '--name',
             '--workspace',
-            '--k8s-namespace',
             '--log-config',
             '--quiet',
             '--quiet-error',
-            '--identity',
             '--workspace-id',
-            '--static-routing-table',
-            '--routing-table',
-            '--dynamic-routing',
             '--extra-search-paths',
-            '--zmq-identity',
-            '--port-ctrl',
-            '--ctrl-with-ipc',
             '--timeout-ctrl',
-            '--ssh-server',
-            '--ssh-keyfile',
-            '--ssh-password',
+            '--k8s-namespace',
+            '--k8s-disable-connection-pool',
+            '--polling',
             '--uses',
             '--uses-with',
             '--uses-metas',
             '--uses-requests',
             '--py-modules',
             '--port-in',
-            '--port-out',
-            '--hosts-in-connect',
             '--host-in',
-            '--host-out',
-            '--socket-in',
-            '--socket-out',
-            '--memory-hwm',
-            '--on-error-strategy',
             '--native',
-            '--num-part',
-            '--dynamic-routing-out',
-            '--dynamic-routing-in',
-            '--grpc-data-requests',
-            '--runs-in-docker',
-            '--dump-path',
-            '--k8s-disable-connection-pool',
             '--entrypoint',
             '--docker-kwargs',
             '--pull-latest',
@@ -379,29 +241,72 @@ ac_table = {
             '--env',
             '--expose-public',
             '--shard-id',
-            '--pea-id',
             '--replica-id',
-            '--pea-role',
+            '--pod-role',
             '--noblock-on-start',
             '--shards',
-            '--parallel',
             '--replicas',
             '--install-requirements',
             '--force-update',
             '--force',
+            '--uses-before-address',
+            '--uses-after-address',
+            '--connection-list',
+        ],
+        'deployment': [
+            '--help',
+            '--name',
+            '--workspace',
+            '--log-config',
+            '--quiet',
+            '--quiet-error',
+            '--workspace-id',
+            '--extra-search-paths',
+            '--timeout-ctrl',
+            '--k8s-namespace',
+            '--k8s-disable-connection-pool',
+            '--polling',
+            '--uses',
+            '--uses-with',
+            '--uses-metas',
+            '--uses-requests',
+            '--py-modules',
+            '--port-in',
+            '--host-in',
+            '--native',
+            '--entrypoint',
+            '--docker-kwargs',
+            '--pull-latest',
+            '--volumes',
+            '--gpus',
+            '--host',
+            '--port-jinad',
+            '--quiet-remote-logs',
+            '--upload-files',
+            '--disable-remote',
+            '--daemon',
+            '--runtime-backend',
+            '--runtime',
+            '--runtime-cls',
+            '--timeout-ready',
+            '--env',
+            '--expose-public',
+            '--shard-id',
+            '--replica-id',
+            '--pod-role',
+            '--noblock-on-start',
+            '--shards',
+            '--replicas',
+            '--install-requirements',
+            '--force-update',
+            '--force',
+            '--uses-before-address',
+            '--uses-after-address',
+            '--connection-list',
             '--uses-before',
             '--uses-after',
-            '--polling',
-            '--scheduling',
             '--external',
-            '--peas-hosts',
-            '--pod-role',
-            '--no-dynamic-routing',
-            '--connect-to-predecessor',
-            '--k8s-uses-init',
-            '--k8s-mount-path',
-            '--k8s-init-container-command',
-            '--k8s-custom-resource-dir',
+            '--deployment-role',
         ],
         'client': [
             '--help',
@@ -410,6 +315,7 @@ ac_table = {
             '--port',
             '--https',
             '--asyncio',
+            '--results-as-docarray',
             '--protocol',
         ],
         'export-api': ['--help', '--yaml-path', '--json-path', '--schema-path'],
