@@ -14,9 +14,11 @@ import signal as _signal
 import sys as _sys
 import types as _types
 import warnings as _warnings
+import docarray as _docarray
 
-if _sys.version_info < (3, 7, 0) or _sys.version_info >= (3, 10, 0):
-    raise OSError(f'Jina requires Python 3.7/3.8/3.9, but yours is {_sys.version_info}')
+
+if _sys.version_info < (3, 7, 0):
+    raise OSError(f'Jina requires Python >= 3.7, but yours is {_sys.version_info}')
 
 __windows__ = _sys.platform == 'win32'
 
@@ -33,7 +35,6 @@ def _warning_on_one_line(message, category, filename, lineno, *args, **kwargs):
 _warnings.formatwarning = _warning_on_one_line
 _warnings.simplefilter('always', DeprecationWarning)
 
-
 # fix fork error on MacOS but seems no effect? must do EXPORT manually before jina start
 _os.environ['OBJC_DISABLE_INITIALIZE_FORK_SAFETY'] = 'YES'
 
@@ -59,11 +60,17 @@ elif _sys.version_info >= (3, 8, 0) and _platform.system() == 'Darwin':
 # this is managed by git tag and updated on every release
 # NOTE: this represents the NEXT release version
 
-__version__ = '2.3.0'
+__version__ = '2.7.0'
 
 # do not change this line manually
 # this is managed by proto/build-proto.sh and updated on every execution
-__proto_version__ = '0.0.86'
+__proto_version__ = '0.1.8'
+try:
+    __docarray_version__ = _docarray.__version__
+except AttributeError as e:
+    raise OSError(
+        '`docarray` dependency is not installed correctly, please reinstall with `pip install -U --force-reinstall docarray`'
+    )
 
 __uptime__ = _datetime.datetime.now().isoformat()
 
@@ -83,13 +90,12 @@ __jina_env__ = (
     'JINA_HUB_ROOT',
     'JINA_K8S_USE_TEST_PIP',
     'JINA_LOG_CONFIG',
-    'JINA_LOG_ID',
     'JINA_LOG_LEVEL',
     'JINA_LOG_NO_COLOR',
     'JINA_LOG_WORKSPACE',
     'JINA_MP_START_METHOD',
     'JINA_OPTIMIZER_TRIAL_WORKSPACE',
-    'JINA_POD_NAME',
+    'JINA_DEPLOYMENT_NAME',
     'JINA_RANDOM_PORT_MAX',
     'JINA_RANDOM_PORT_MIN',
     'JINA_VCS_VERSION',
@@ -100,6 +106,7 @@ __default_host__ = _os.environ.get(
 )
 __docker_host__ = 'host.docker.internal'
 __default_executor__ = 'BaseExecutor'
+__default_reducer_executor__ = 'ReducerExecutor'
 __default_endpoint__ = '/default'
 __ready_msg__ = 'ready and listening'
 __stop_msg__ = 'terminated'
@@ -108,8 +115,6 @@ __args_executor_func__ = {
     'docs',
     'parameters',
     'docs_matrix',
-    'groundtruths',
-    'groundtruths_matrix',
 }
 __args_executor_init__ = {'metas', 'requests', 'runtime_args'}
 __root_dir__ = _os.path.dirname(_os.path.abspath(__file__))
@@ -140,7 +145,10 @@ JINA_GLOBAL.tensorflow_installed = None
 JINA_GLOBAL.torch_installed = None
 JINA_GLOBAL.dgl_installed = None
 
-_signal.signal(_signal.SIGINT, _signal.default_int_handler)
+try:
+    _signal.signal(_signal.SIGINT, _signal.default_int_handler)
+except Exception as exc:
+    _warnings.warn(f'failed to set default signal handler: {exc!r}`')
 
 
 def _set_nofile(nofile_atleast=4096):
@@ -191,17 +199,15 @@ _set_nofile()
 from jina.clients import Client
 
 # Document
-from jina.types.document import Document
-from jina.types.arrays.document import DocumentArray
-from jina.types.arrays.memmap import DocumentArrayMemmap
+from docarray import Document, DocumentArray
 
 # Executor
-from jina.executors import BaseExecutor as Executor
-from jina.executors.decorators import requests
+from jina.serve.executors import BaseExecutor as Executor
+from jina.serve.executors.decorators import requests
 
 # Flow
-from jina.flow.base import Flow
-from jina.flow.asyncio import AsyncFlow
+from jina.orchestrate.flow.base import Flow
+from jina.orchestrate.flow.asyncio import AsyncFlow
 
 __all__ = [_s for _s in dir() if not _s.startswith('_')]
 __all__.extend(_names_with_underscore)
