@@ -6,19 +6,19 @@ import json
 import os
 import random
 from pathlib import Path
-from typing import Optional, Dict
+from typing import Optional
 from urllib.parse import urlencode
 
-from . import HubExecutor
-from .helper import (
+from jina.hubble import HubExecutor
+from jina.hubble.helper import (
     archive_package,
     download_with_resume,
+    get_hubble_url_v2,
     parse_hub_uri,
-    get_hubble_url,
     upload_file,
     disk_cache_offline,
 )
-from .hubapi import (
+from jina.hubble.hubapi import (
     install_local,
     get_dist_path_of_executor,
     load_secret,
@@ -26,11 +26,11 @@ from .hubapi import (
     get_lockfile,
     install_package_dependencies,
 )
-from .. import __resources_path__
-from ..helper import get_full_version, ArgNamespace
-from ..importer import ImportExtensions
-from ..logging.logger import JinaLogger
-from ..parsers.hubble import set_hub_parser
+from jina import __resources_path__, __version__
+from jina.helper import ArgNamespace, colored, get_request_header
+from jina.importer import ImportExtensions
+from jina.logging.logger import JinaLogger
+from jina.parsers.hubble import set_hub_parser
 
 _cache_file = Path.home().joinpath('.jina', 'disk_cache.db')
 
@@ -67,20 +67,6 @@ class HubIO:
             assert cryptography
             assert filelock
 
-    @staticmethod
-    def _get_request_header() -> Dict:
-        """Return the header of request.
-
-        :return: request header
-        """
-        metas, envs = get_full_version()
-
-        header = {
-            **{f'jinameta-{k}': str(v) for k, v in metas.items()},
-            **envs,
-        }
-        return header
-
     def new(self) -> None:
         """Create a new executor folder interactively."""
 
@@ -336,7 +322,7 @@ metas:
         console.print(p)
 
     def push(self) -> None:
-        """Push the executor pacakge to Jina Hub."""
+        """Push the executor package to Jina Hub."""
 
         from rich.console import Console
 
@@ -360,7 +346,7 @@ metas:
 
         console = Console()
         with console.status(f'Pushing `{self.args.path}` ...') as st:
-            req_header = self._get_request_header()
+            req_header = get_request_header()
             try:
                 st.update(f'Packaging {self.args.path} ...')
                 md5_hash = hashlib.md5()
@@ -378,6 +364,9 @@ metas:
                     'md5sum': md5_digest,
                 }
 
+                if self.args.verbose:
+                    form_data['verbose'] = 'True'
+
                 if exec_tags:
                     form_data['tags'] = exec_tags
 
@@ -386,14 +375,15 @@ metas:
 
                 uuid8, secret = load_secret(work_path)
                 if self.args.force_update or uuid8:
-                    form_data['force'] = self.args.force_update or uuid8
+                    form_data['id'] = self.args.force_update or uuid8
                 if self.args.secret or secret:
                     form_data['secret'] = self.args.secret or secret
 
-                method = 'put' if ('force' in form_data) else 'post'
-
                 st.update(f'Connecting to Jina Hub ...')
-                hubble_url = get_hubble_url()
+                if form_data.get('id') and form_data.get('secret'):
+                    hubble_url = get_hubble_url_v2() + '/rpc/executor.update'
+                else:
+                    hubble_url = get_hubble_url_v2() + '/rpc/executor.create'
 
                 # upload the archived executor to Jina Hub
                 st.update(f'Uploading...')
@@ -404,59 +394,77 @@ metas:
                     dict_data=form_data,
                     headers=req_header,
                     stream=True,
-                    method=method,
+                    method='post',
                 )
 
-                result = None
+                image = None
                 for stream_line in resp.iter_lines():
                     stream_msg = json.loads(stream_line)
 
-                    if 'stream' in stream_msg:
-                        st.update(
-                            f'Cloud building ... [dim]{stream_msg["stream"]}[/dim]'
-                        )
-                    elif 'status' in stream_msg:
-                        st.update(
-                            f'Cloud building ... [dim]{stream_msg["status"]}[/dim]'
-                        )
-                    elif 'result' in stream_msg:
-                        result = stream_msg['result']
-                        break
+                    t = stream_msg.get('type')
+                    subject = stream_msg.get('subject')
+                    payload = stream_msg.get('payload', '')
+                    if t == 'error':
+                        msg = stream_msg.get('message')
+                        if payload and isinstance(payload, dict):
+                            msg = payload.get('message')
 
-                if result is None:
-                    raise Exception('Unknown Error')
-                elif not result.get('data', None):
-                    raise Exception(result.get('message', 'Unknown Error'))
-                elif 200 <= result['statusCode'] < 300:
-                    new_uuid8, new_secret = self._prettyprint_result(console, result)
+                        if 'Process(docker) exited on non-zero code' in msg:
+                            self.logger.error(
+                                '''
+                            Failed on building Docker image. Potential solutions:
+                            - If you haven't provide a Dockerfile in the executor bundle, you may want to provide one,
+                              as the auto-generated one on the cloud did not work.
+                            - If you have provided a Dockerfile, you may want to check the validity of this Dockerfile.
+                            '''
+                            )
+
+                        raise Exception(msg or 'Unknown Error')
+                    if t == 'progress' and subject == 'buildWorkspace':
+                        legacy_message = stream_msg.get('legacyMessage', {})
+                        status = legacy_message.get('status', '')
+                        st.update(
+                            f'Cloud building ... [dim]{subject}: {t} ({status})[/dim]'
+                        )
+                    elif t == 'complete':
+                        image = stream_msg['payload']
+                        st.update(
+                            f'Cloud building ... [dim]{subject}: {t} ({stream_msg["message"]})[/dim]'
+                        )
+                        break
+                    elif t and subject:
+                        if self.args.verbose and t == 'console':
+                            console.log(
+                                f'Cloud building ... [dim]{subject}: {payload}[/dim]'
+                            )
+                        else:
+                            st.update(
+                                f'Cloud building ... [dim]{subject}: {t} {payload}[/dim]'
+                            )
+
+                if image:
+                    new_uuid8, new_secret = self._prettyprint_result(console, image)
                     if new_uuid8 != uuid8 or new_secret != secret:
                         dump_secret(work_path, new_uuid8, new_secret)
-                elif result['message']:
-                    raise Exception(result['message'])
-                elif resp.text:
-                    # NOTE: sometimes resp.text returns empty
-                    raise Exception(resp.text)
                 else:
-                    resp.raise_for_status()
+                    raise Exception('Unknown Error')
 
             except KeyboardInterrupt:
                 pass
 
             except Exception as e:  # IO related errors
                 self.logger.error(
-                    f'Error while pushing session_id={req_header["jinameta-session-id"]}: '
-                    f'\n{e!r}'
+                    f'''Please report this session_id: {colored(req_header["jinameta-session-id"], color="yellow", attrs="bold")} to https://github.com/jina-ai/jina/issues'
+                {e!r}'''
                 )
                 raise e
 
-    def _prettyprint_result(self, console, result):
+    def _prettyprint_result(self, console, image):
         # TODO: only support single executor now
 
         from rich.table import Table
         from rich.panel import Panel
 
-        data = result.get('data', None)
-        image = data['executors'][0]
         uuid8 = image['id']
         secret = image['secret']
         visibility = image['visibility']
@@ -484,7 +492,6 @@ metas:
             width=80,
             expand=False,
         )
-
         console.print(p1)
 
         presented_id = image.get('name', uuid8)
@@ -566,34 +573,104 @@ with f:
         with ImportExtensions(required=True):
             import requests
 
-        pull_url = get_hubble_url() + f'/{name}/?'
+        pull_url = get_hubble_url_v2() + f'/rpc/executor.getPackage?id={name}'
         path_params = {}
         if secret:
             path_params['secret'] = secret
         if tag:
             path_params['tag'] = tag
         if path_params:
-            pull_url += urlencode(path_params)
+            pull_url += f'&{urlencode(path_params)}'
 
-        resp = requests.get(pull_url, headers=HubIO._get_request_header())
+        resp = requests.get(pull_url, headers=get_request_header())
         if resp.status_code != 200:
             if resp.text:
                 raise Exception(resp.text)
             resp.raise_for_status()
 
-        resp = resp.json()
+        resp = resp.json()['data']
 
         return HubExecutor(
             uuid=resp['id'],
             name=resp.get('name', None),
             sn=resp.get('sn', None),
-            tag=tag or resp['tag'],
+            tag=tag or resp['commit'].get('tags', [None])[0],
             visibility=resp['visibility'],
-            image_name=resp['image'],
+            image_name=resp['package'].get('containers', [None])[0],
             archive_url=resp['package']['download'],
             md5sum=resp['package']['md5'],
         )
 
+    @staticmethod
+    def deploy_public_sandbox(uses: str):
+        """
+        Deploy a public sandbox to Jina Hub.
+        :param uses: the executor uses string
+
+        :return: the host and port of the sandbox
+        """
+        scheme, name, tag, secret = parse_hub_uri(uses)
+        payload = {
+            'name': name,
+            'tag': tag if tag else 'latest',
+            'jina': __version__,
+        }
+
+        from rich.progress import Console
+        import requests
+
+        console = Console()
+
+        host = None
+        port = None
+        try:
+            json_response = requests.get(
+                url=get_hubble_url_v2() + '/rpc/sandbox.get',
+                params=payload,
+                headers=get_request_header(),
+            ).json()
+            if json_response.get('code') == 200:
+                host = json_response.get('data', {}).get('host', None)
+                port = json_response.get('data', {}).get('port', None)
+                livetime = json_response.get('data', {}).get('livetime', '15 mins')
+
+        except Exception:
+            raise
+
+        if host and port:
+            console.log(f"There is already one sandbox existing, reusing it.")
+            console.log(
+                f"[bold green]This sandbox will be removed when no traffic during {livetime}"
+            )
+
+            return host, port
+
+        with console.status(
+            f"[bold green]Deploying sandbox for ({name}) since no existing one..."
+        ):
+            try:
+                json_response = requests.post(
+                    url=get_hubble_url_v2() + '/rpc/sandbox.create',
+                    json=payload,
+                    headers=get_request_header(),
+                ).json()
+
+                host = json_response.get('data', {}).get('host', None)
+                port = json_response.get('data', {}).get('port', None)
+                livetime = json_response.get('data', {}).get('livetime', '15 mins')
+                if not host or not port:
+                    raise Exception(f'Failed to deploy sandbox: {json_response}')
+
+                console.log(f"Deployment completed: {host}:{port}")
+                console.log(
+                    f"[bold green]This sandbox will be removed when no traffic during {livetime}"
+                )
+            except:
+                console.log("Deployment failed")
+                raise
+
+        return host, port
+
     def _pull_with_progress(self, log_streams, console):
         from rich.progress import Progress, DownloadColumn, BarColumn
 
@@ -638,7 +715,7 @@ with f:
             import docker
             from docker import APIClient
 
-            from .. import __windows__
+            from jina import __windows__
 
             try:
                 self._client = docker.from_env()
@@ -673,7 +750,9 @@ with f:
                 scheme, name, tag, secret = parse_hub_uri(self.args.uri)
 
                 st.update(f'Fetching [bold]{name}[/bold] from Jina Hub ...')
-                executor = HubIO.fetch_meta(name, tag, secret=secret, force=need_pull)
+                executor, from_cache = HubIO.fetch_meta(
+                    name, tag, secret=secret, force=need_pull
+                )
 
                 presented_id = getattr(executor, 'name', executor.uuid)
                 executor_name = (
@@ -732,9 +811,10 @@ with f:
 
                         if need_pull:
                             # pull the latest executor meta, as the cached data would expire
-                            executor = HubIO.fetch_meta(
-                                name, tag, secret=secret, force=True
-                            )
+                            if from_cache:
+                                executor, _ = HubIO.fetch_meta(
+                                    name, tag, secret=secret, force=True
+                                )
 
                             cache_dir = Path(
                                 os.environ.get(
