@@ -1,37 +1,6 @@
-import argparse
-
 from jina.parsers.client import mixin_comm_protocol_parser
-from .helper import _SHOW_ALL_ARGS
-
-
-def set_pea_parser(parser=None):
-    """Set the parser for the Pea
-
-    :param parser: an optional existing parser to build upon
-    :return: the parser
-    """
-    if not parser:
-        from .base import set_base_parser
-
-        parser = set_base_parser()
-
-    from .peapods.base import mixin_base_ppr_parser
-    from .peapods.runtimes.zmq import mixin_zmq_runtime_parser
-    from .peapods.runtimes.zed import mixin_zed_runtime_parser
-    from .peapods.runtimes.container import mixin_container_runtime_parser
-    from .peapods.runtimes.remote import mixin_remote_parser
-    from .peapods.pea import mixin_pea_parser
-    from .peapods.runtimes.distributed import mixin_distributed_feature_parser
-
-    mixin_base_ppr_parser(parser)
-    mixin_zmq_runtime_parser(parser)
-    mixin_zed_runtime_parser(parser)
-    mixin_container_runtime_parser(parser)
-    mixin_remote_parser(parser)
-    mixin_distributed_feature_parser(parser)
-    mixin_pea_parser(parser)
-
-    return parser
+from jina.parsers.helper import _SHOW_ALL_ARGS
+from jina.parsers.orchestrate.runtimes.head import mixin_head_parser
 
 
 def set_pod_parser(parser=None):
@@ -41,15 +10,50 @@ def set_pod_parser(parser=None):
     :return: the parser
     """
     if not parser:
-        from .base import set_base_parser
+        from jina.parsers.base import set_base_parser
 
         parser = set_base_parser()
 
-    set_pea_parser(parser)
+    from jina.parsers.orchestrate.base import mixin_base_ppr_parser
+    from jina.parsers.orchestrate.runtimes.worker import mixin_worker_runtime_parser
+    from jina.parsers.orchestrate.runtimes.container import (
+        mixin_container_runtime_parser,
+    )
+    from jina.parsers.orchestrate.runtimes.remote import mixin_remote_runtime_parser
+    from jina.parsers.orchestrate.pod import mixin_pod_parser
+    from jina.parsers.orchestrate.runtimes.distributed import (
+        mixin_distributed_feature_parser,
+    )
+    from jina.parsers.hubble.pull import mixin_hub_pull_options_parser
 
-    from .peapods.pod import mixin_base_pod_parser
+    mixin_base_ppr_parser(parser)
+    mixin_worker_runtime_parser(parser)
+    mixin_container_runtime_parser(parser)
+    mixin_remote_runtime_parser(parser)
+    mixin_distributed_feature_parser(parser)
+    mixin_pod_parser(parser)
+    mixin_hub_pull_options_parser(parser)
+    mixin_head_parser(parser)
 
-    mixin_base_pod_parser(parser)
+    return parser
+
+
+def set_deployment_parser(parser=None):
+    """Set the parser for the Deployment
+
+    :param parser: an optional existing parser to build upon
+    :return: the parser
+    """
+    if not parser:
+        from jina.parsers.base import set_base_parser
+
+        parser = set_base_parser()
+
+    set_pod_parser(parser)
+
+    from jina.parsers.orchestrate.deployment import mixin_base_deployment_parser
+
+    mixin_base_deployment_parser(parser)
 
     return parser
 
@@ -61,46 +65,37 @@ def set_gateway_parser(parser=None):
     :return: the parser
     """
     if not parser:
-        from .base import set_base_parser
+        from jina.parsers.base import set_base_parser
 
         parser = set_base_parser()
 
-    from .peapods.base import mixin_base_ppr_parser
-    from .peapods.runtimes.zmq import mixin_zmq_runtime_parser
-    from .peapods.runtimes.zed import mixin_zed_runtime_parser
-    from .peapods.runtimes.remote import (
-        mixin_remote_parser,
+    from jina.parsers.orchestrate.base import mixin_base_ppr_parser
+    from jina.parsers.orchestrate.runtimes.worker import mixin_worker_runtime_parser
+    from jina.parsers.orchestrate.runtimes.remote import (
+        mixin_gateway_parser,
         mixin_prefetch_parser,
         mixin_http_gateway_parser,
         mixin_compressor_parser,
     )
-    from .peapods.pea import mixin_pea_parser
+    from jina.parsers.orchestrate.deployment import mixin_base_deployment_parser
+    from jina.parsers.orchestrate.pod import mixin_pod_parser
 
     mixin_base_ppr_parser(parser)
-    mixin_zmq_runtime_parser(parser)
-    mixin_zed_runtime_parser(parser)
+    mixin_worker_runtime_parser(parser)
     mixin_prefetch_parser(parser)
     mixin_http_gateway_parser(parser)
     mixin_compressor_parser(parser)
     mixin_comm_protocol_parser(parser)
-    mixin_remote_parser(parser)
-    mixin_pea_parser(parser)
+    mixin_gateway_parser(parser)
+    mixin_pod_parser(parser)
+    mixin_head_parser(parser)
 
-    from ..enums import SocketType, PodRoleType
+    from jina.enums import DeploymentRoleType
 
     parser.set_defaults(
         name='gateway',
-        socket_in=SocketType.PULL_CONNECT,  # otherwise there can be only one client at a time
-        socket_out=SocketType.PUSH_CONNECT,
-        ctrl_with_ipc=True,  # otherwise ctrl port would be conflicted
-        runtime_cls='GRPCRuntime',
-        pod_role=PodRoleType.GATEWAY,
-    )
-
-    parser.add_argument(
-        '--routing-table',
-        type=str,
-        help='Routing graph for the gateway' if _SHOW_ALL_ARGS else argparse.SUPPRESS,
+        runtime_cls='GRPCGatewayRuntime',
+        deployment_role=DeploymentRoleType.GATEWAY,
     )
 
     return parser
@@ -113,36 +108,57 @@ def set_client_cli_parser(parser=None):
     :return: the parser
     """
     if not parser:
-        from .base import set_base_parser
+        from jina.parsers.base import set_base_parser
 
         parser = set_base_parser()
 
-    from .peapods.runtimes.remote import mixin_remote_parser
-    from .client import mixin_client_features_parser, mixin_comm_protocol_parser
+    from jina.parsers.orchestrate.runtimes.remote import mixin_client_gateway_parser
+    from jina.parsers.client import (
+        mixin_client_features_parser,
+        mixin_comm_protocol_parser,
+    )
 
-    mixin_remote_parser(parser)
+    mixin_client_gateway_parser(parser)
     mixin_client_features_parser(parser)
     mixin_comm_protocol_parser(parser)
 
     return parser
 
 
+def set_help_parser(parser=None):
+    """Set the parser for the jina help lookup
+
+    :param parser: an optional existing parser to build upon
+    :return: the parser
+    """
+
+    if not parser:
+        from jina.parsers.base import set_base_parser
+
+        parser = set_base_parser()
+
+    parser.add_argument(
+        'query',
+        type=str,
+        help='Lookup the usage & mention of the argument name in Jina API. The name can be fuzzy',
+    )
+    return parser
+
+
 def get_main_parser():
     """The main parser for Jina
 
     :return: the parser
     """
-    from .base import set_base_parser
-    from .helloworld import set_hello_parser
-    from .helper import _chf, _SHOW_ALL_ARGS
+    from jina.parsers.base import set_base_parser
+    from jina.parsers.helloworld import set_hello_parser
+    from jina.parsers.helper import _chf, _SHOW_ALL_ARGS
 
-    from .export_api import set_export_api_parser
-    from .flow import set_flow_parser
-    from .ping import set_ping_parser
+    from jina.parsers.export_api import set_export_api_parser
+    from jina.parsers.flow import set_flow_parser
+    from jina.parsers.ping import set_ping_parser
 
-    from .hubble import set_hub_parser
-
-    # from .optimizer import set_optimizer_parser
+    from jina.parsers.hubble import set_hub_parser
 
     # create the top-level parser
     parser = set_base_parser()
@@ -169,7 +185,6 @@ def get_main_parser():
     set_pod_parser(
         sp.add_parser(
             'executor',
-            aliases=['pod'],
             help='Start an Executor',
             description='Start an Executor. Executor is how Jina processes Document.',
             formatter_class=_chf,
@@ -189,7 +204,7 @@ def get_main_parser():
         sp.add_parser(
             'ping',
             help='Ping an Executor',
-            description='Ping a Pod and check its network connectivity.',
+            description='Ping a Deployment and check its network connectivity.',
             formatter_class=_chf,
         )
     )
@@ -212,16 +227,35 @@ def get_main_parser():
         )
     )
 
+    set_help_parser(
+        sp.add_parser(
+            'help',
+            help='Show help text of a CLI argument',
+            description='Show help text of a CLI argument',
+            formatter_class=_chf,
+        )
+    )
     # Below are low-level / internal / experimental CLIs, hidden from users by default
 
-    set_pea_parser(
+    set_pod_parser(
         sp.add_parser(
-            'pea',
-            description='Start a Pea. '
+            'pod',
+            description='Start a Pod. '
             'You should rarely use this directly unless you '
             'are doing low-level orchestration',
             formatter_class=_chf,
-            **(dict(help='Start a Pea')) if _SHOW_ALL_ARGS else {},
+            **(dict(help='Start a Pod')) if _SHOW_ALL_ARGS else {},
+        )
+    )
+
+    set_deployment_parser(
+        sp.add_parser(
+            'deployment',
+            description='Start a Deployment. '
+            'You should rarely use this directly unless you '
+            'are doing low-level orchestration',
+            formatter_class=_chf,
+            **(dict(help='Start a Deployment')) if _SHOW_ALL_ARGS else {},
         )
     )
 
